pub fn to_mf2_document(
resp: Response<Body>,
page_url: &str,
) -> Result<Document, Error>Expand description
Converts this response into a [MF2 document][microformats::types::Document].
Errors
This function will return an error if it could not detect the content type of this request or fails to convert it into a MF2 document.